import React, { Component } from 'react';
import { PlusOutlined } from "@ant-design/icons";
import {
  Button,
  message,
  AutoComplete,
  Form,
  Select,
} from "antd";
import ProForm, {
  DrawerForm,
  ProFormSelect,
} from '@ant-design/pro-form';
import {
  orderTypes,
  customerType,
} from "@/utils/dataDic";
import {getCustomerByName, createOrder} from '../services/API';

const { Option } = Select;

class CreateOrder extends Component{
  constructor(props) {
    super(props);
    this.state={
      customerOptions: [],
      customType: '',
      uid: '',
    }
    this.selectCustomerType = this.selectCustomerType.bind(this);
    this.onSearch = this.onSearch.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  selectCustomerType=(v)=>{
    this.setState({
      customType: v,
    })
  }

  onSearch= async (v)=>{
    if(!this.state.customType){
      message.warning('请先选择客户所属类型!')
      return;
    }
    const msg = await getCustomerByName(v,this.state.customType);
    if(msg.error.length === 0){
      (msg.data || []).map((v)=>{
        v.label = v.name;
        v.value = v.name;
        return v
      })
      this.setState({
        customerOptions: msg.data || [],
      })
    }else{
      message.info(msg.error[0].message)
    }
  }

  handleSubmit= async (v)=>{
    const msg = await createOrder(this.state.uid,v.orderType);
    if(msg.error.length === 0){
      message.success('创建成功');
      this.props.dataTableRef.current && this.props.dataTableRef.current.reload();// 刷新列表
      return true;
    }else{
      message.info(msg.error[0].message)
    }
    return false;
  }

  render() {
    return (
      <>
        <DrawerForm
          title="创建订单"
          trigger={
            <Button key="button" icon={<PlusOutlined />} type="primary">
              开单
            </Button>
          }
          onFinish={this.handleSubmit}
        >
          <ProForm.Group>
            <ProFormSelect
              options={
                orderTypes.map((v)=>{
                  v.label = v.key;
                  return v;
                })
              }
              width="xl"
              name="orderType"
              label="订单类型"
              rules={[{ required: true }]}
              placeholder='请选择订单类型'
            />
          </ProForm.Group>
          <ProForm.Group>
            <Form.Item
              name="customType"
              label="客户所属类型"
              rules={[{ required: true }]}
            >
              <Select
                placeholder='请选择客户所属类型'
                style={{ width: 552 }}
                onChange={this.selectCustomerType}
              >
                {
                  customerType.map((value,key)=>(
                    <Option value={value.value} key={key}>{value.key}</Option>
                  ))
                }

              </Select>
            </Form.Item>
          </ProForm.Group>
          <ProForm.Group>
            <Form.Item
              name="uid"
              label="客户名称"
              rules={[{ required: true }]}
            >
              <AutoComplete
                options={this.state.customerOptions}
                style={{ width: 552 }}
                onSelect={(v)=>{
                  this.setState({
                    uid: this.state.customerOptions.filter(item=> item.name === v)[0]['id'],
                  })
                }}
                onSearch={this.onSearch}
                placeholder="请输入名称"
              />
            </Form.Item>
          </ProForm.Group>
        </DrawerForm>
      </>
    )
  }
}

export default CreateOrder;
