import React,{Component} from "react";
import ProForm, {ModalForm, ProFormSelect, ProFormText} from "@ant-design/pro-form";
import { LoadingOutlined,ExclamationCircleOutlined } from '@ant-design/icons';
import {getSuperList,addVarieties,getDetailVarieties,setEditVarieties} from '../services/API';
import {splitUrl} from '@/utils/tools';
import {Form, message, Modal, Select, Spin} from "antd";
import {connectModel} from "@/services/common";
import ImgOperation from "@/components/common/ImgOperation";

const antIcon = <LoadingOutlined style={{ fontSize: 24 }} spin />;
const confirm = Modal.confirm;

@connectModel('test', '@@initialState')
class CategoryOperation extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading:false,
      fileList: [],
      uploadImgLoading: false,
      superId: '',
    }
  }

  inquiry=(value)=>{
    if(this.state.uploadImgLoading){
      message.info('有图片正在上传中,请稍后');
      return false;
    }

    let statusLv = value.status === '1';
    let superNameLv = value.superId !== this.state.superId;
    let _this = this;
    if(statusLv || superNameLv){
      confirm({
        title:'修改提醒',
        icon: <ExclamationCircleOutlined />,
        content: statusLv && superNameLv ? '确定要修改该品类的上级品类并且停用该品类吗?' : statusLv ? '确定要停用该品类吗?' : '确定要修改该品类的上级品类吗?',
        onOk() {
          _this.updateType(value);
        }
      })
    }else{
      this.updateType(value);
    }
  }

  updateType= async (value)=>{
    let thecompanyLogoUrl = [];
    if(this.state.fileList.length) {
      let picArr = [];
      this.state.fileList.map((item) => {
        picArr.push(item.response.data);
      });
      thecompanyLogoUrl = picArr.join(",");
    };
    message.loading({content:'修改中...',key:'setEditVarieties'});
    const msg = await setEditVarieties({
      id: this.props.typeInfor.id, // 品类ID
      cname: value.cname, // 品类名称
      superId: value.superId, // 上级品类
      status: value.status, // 品类状态
      varietiesLogo: thecompanyLogoUrl,
      sort: value.sort
    });
    if(msg.error.length === 0){
      message.success({content:'修改成功',key:'setEditVarieties',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'setEditVarieties',duration:"2.5"});
    }
  }

  getCategoryStateList=async ()=>{
    return [
      {
        label: '正常',
        value: '0',
      },
      {
        label: '停用',
        value: '1',
      }
    ];
  }

  addType= async (value)=>{
    message.loading({content:'保存中...',key:'addType'})
    const msg = await addVarieties(value.cname,value.superId);
    if(msg.error.length === 0){
     message.success({content:'保存成功',key:'addType',duration:2.5});
     this.props.formRef.current.reload();
     this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addType',duration:2.5});
    }
  }

  getSuperList= async ()=>{
    const msg = await getSuperList(1);
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.cname,
          value: item.id
        });
      });
    }else{
      message.error(msg.error.message);
    }
    return theArr;
  }

  getDetailVarieties=async ()=>{
    this.setState({
      loading: true,
    })
    const msg = await getDetailVarieties(this.props.typeInfor.id);
    if(msg.error.length === 0){
      this.formRef.current.setFieldsValue({
        cname: msg.data.cname,
        superId: msg.data.superId,
        status: msg.data.status,
        sort: msg.data.sort,
        layer: msg.data.layer,
        cid: msg.data.cid,
        createName: msg.data.createName,
        createTimeFormattedDate: msg.data.createTimeFormattedDate,
        varietiesLogo:msg.data.varietiesLogo? splitUrl(msg.data.varietiesLogo, ',', this.props.test.initialState.globalConfig.avatarHost + '/upload').fileList : [],
      });
      this.setState({
        superId: msg.data.superId,
        fileList: msg.data.varietiesLogo? splitUrl(msg.data.varietiesLogo, ',', this.props.test.initialState.globalConfig.avatarHost + '/upload').fileList : []
      })
    }else{
      message.error(msg.error[0].message);
    }
    this.setState({
      loading: false,
    })
  }

  componentDidMount() {
    if(this.props.typeInfor.id){
      this.getDetailVarieties();
    }
  }

  formRef = React.createRef();

  render() {
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title={this.props.typeInfor ? '编辑种类' : '新建种类'}
        modalProps={{
          width:400,
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();},
        }}
        onFinish={this.props.typeInfor ? this.inquiry : this.addType}
      >
        <Spin spinning={this.state.loading} indicator={antIcon}>
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入品类名称'
                }
              ]}
              placeholder="请输入品类名称"
              name="cname"
              label="品类名称"/>
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              width="m"
              label='上级品类'
              name="superId"
              placeholder="请选择上级品类"
              rules={[
                {
                  required:true,
                  message:'请选择上级品类'
                }
              ]}
              request={this.getSuperList}/>
          </ProForm.Group>
          {this.props.typeInfor && <>
            <ProForm.Group>
              <ProFormSelect
                width="m"
                label='品类状态'
                name="status"
                placeholder="请选择品类状态"
                rules={[
                  {
                    required:true,
                    message:'请选择品类状态'
                  }
                ]}
                request={this.getCategoryStateList}/>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                rules={[
                  {
                    required:true,
                    message:'请输入品类序号'
                  }
                ]}
                placeholder="请输入品类序号"
                name="sort"
                label="品类序号"/>
            </ProForm.Group>
            <ProForm.Group>
              <Form.Item label='业务品类图标'  name="varietiesLogo" extra="图片建议：要清晰。">
                <ImgOperation
                  domId='varietiesLogo'
                  uploadConfig={{
                    action:'/api/admin/Varieties/uploadPicture',
                    multiple:true,
                    data:{ 'sign': 'varieties_picture' },
                    listType:"picture-card",
                  }}
                  onChange={(infor)=>{
                    this.setState({
                      fileList: infor.fileList,
                    });
                  }}
                  fileList={this.state.fileList}
                  onUploadState={(v)=>{
                    this.setState({
                      uploadImgLoading: v.state === 'uploading'
                    })
                  }}
                />
              </Form.Item>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                readonly
                name="layer"
                label="品类层级"/>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                readonly
                name="cid"
                label="品类编号"/>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                readonly
                name="createName"
                label="创建人"/>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                readonly
                name="createTimeFormattedDate"
                label="创建时间"/>
            </ProForm.Group>
          </>}
        </Spin>
      </ModalForm>
    )
  }
}

export default CategoryOperation;
