import React, { Component }from 'react';
import {Button, message, Popconfirm} from "antd";
import DataTable from "@/components/common/DataTable";
import NewPermission from './components/newPermission';
import AuthorityDetails from './components/AuthorityDetails';
import {deleteById} from './services/API';
import {PlusOutlined} from "@ant-design/icons";

class Jurisdiction extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns:[
        {
        title: '接口名称',
        dataIndex: 'name',
        key: 'name',
        width: '400px'
      }, {
        title: '接口路径',
        dataIndex: 'url',
        key: 'url',
      }, {
        title: '操作',
        dataIndex: 'id',
        key: 'id',
        render: (text, record, key, action) => {
          return(
            <>
              {
                record.url.indexOf('.html#')<=0 &&
                <Button
                  type="primary"
                  key='addSupPermission'
                  style={{marginRight:'15px'}}
                  onClick={(e)=>{e.stopPropagation();this.setState({newPermissionVisible:true,superData:record})}}>
                  新增下级权限
                </Button>
              }
              <Popconfirm
                title="是否真的删除?"
                onConfirm={(e)=>{e.stopPropagation();this.delectRow(record.id,action)}}
                okText="确认"
                cancelText="取消"
                placement="topLeft">
                <Button type="danger" onClick={(e)=>{e.stopPropagation();}}>删除</Button>
              </Popconfirm>
            </>
          )
        }
      }],
      detailsVisible:false,
      detailsInfor:{},
      newPermissionVisible: false,
      superData:{},
    };

    this.delectRow = this.delectRow.bind(this);
    this.onRow = this.onRow.bind(this);
  }

  onRow=(event,record)=>{
    event.stopPropagation();
    this.setState({
      detailsVisible: true,
      detailsInfor:record
    })

    console.log(record)
  }

  delectRow=async (id,action)=>{
    message.loading({ content: '删除中...', key:'delectRow' });
    const msg = await deleteById(id);
    if(msg.error.length === 0){
      message.success({ content: '删除成功!', key:'delectRow', duration: 2 });
      action.reload();
    }else{
      message.error({content:msg.error[0].message, key:'delectRow', duration: 2} );
    }
  }

  onCancel=()=>{
    this.setState({
      detailsVisible: false
    })
  }

  onNewPermissionCancel=()=>{
    this.setState({
      newPermissionVisible: false,
      superData:'',
    })
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          headerTitle='权限管理'
          url='/api/admin/permissions'
          method='post'
          rowKey='id'
          scroll={{ x: 900 }}
          columns={this.state.columns}
          search={false}
          pagination={false}
          onRow={(record)=>({
              onClick:event => this.onRow(event,record)
            })}
          toolBarRender={[
            <Button
              type="primary"
              key='NewPermission'
              icon={<PlusOutlined />}
              onClick={()=>{
                this.setState({
                  newPermissionVisible: true,
                  superData:'',
                })
              }}
            >
              新增权限
            </Button>
          ]}
        />
        {this.state.detailsVisible && <AuthorityDetails
          tableRef={ref}
          detailsInfor={this.state.detailsInfor}
          visible={this.state.detailsVisible}
          onCancel={this.onCancel}
        />}
        {this.state.newPermissionVisible &&
          <NewPermission
            tableRef={ref}
            superData={this.state.superData}
            visible={this.state.newPermissionVisible}
            onCancel={this.onNewPermissionCancel}
          />
        }
      </>
    )
  }
}

export default Jurisdiction;
