import React,{Component} from 'react';
import ProForm, {ModalForm, ProFormText} from "@ant-design/pro-form";
import {addRole,getPermissions,getRolePermission} from '../services/API';
import {Spin, message,Tree,Form} from "antd";

class EditRole extends Component{
  constructor(props) {
    super(props);
    this.state={
      permissionsList:[],
      expandedKeys:'',
      checkedKeys: '',
      selectedKeys: '',
      roleNameLoading: false,
      treeLoading: false,
    }
    this.finishAddRole = this.finishAddRole.bind(this);
    this.finishUpdataRole = this.finishUpdataRole.bind(this);
    this.onSelect = this.onSelect.bind(this);
    this.onExpand = this.onExpand.bind(this);
    this.onCheck = this.onCheck.bind(this);
    this.getPermissionsList = this.getPermissionsList.bind(this);
    this.handlePermissionsList = this.handlePermissionsList.bind(this);
  }

  finishAddRole= async (value)=>{
    let obj = Object.assign({permissions:this.state.checkedKeys || []},value)
    message.loading({content:'添加中...',key:'finishAddRole'})
    const msg = await addRole({data:JSON.stringify(obj)});
    if(msg.error.length === 0){
      message.success({content:'添加成功',key:'finishAddRole',duration:2.5});
      this.props.tableRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'finishAddRole',duration:2.5});
      return false;
    }
  }

  finishUpdataRole= async (value)=>{
    value.id = this.props.roleData.id;
    let obj = Object.assign({permissions:this.state.checkedKeys || []},value)
    message.loading({content:'修改中...',key:'finishUpdataRole'})
    const msg = await addRole({data:JSON.stringify(obj)});
    if(msg.error.length === 0){
      message.success({content:'修改成功',key:'finishUpdataRole',duration:2.5});
      this.props.tableRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'finishUpdataRole',duration:2.5});
    }
  }

  onExpand=(expandedKeys)=>{
    this.setState({
      expandedKeys:expandedKeys,
      autoExpandParent:false,
    })
  }

  onCheck=(checkedKeys)=>{
    this.setState({
      checkedKeys: checkedKeys
    })
  }

  onSelect=(selectedKeys)=>{
    this.setState({
      selectedKeys: selectedKeys
    })
  }

  getPermissionsList= async ()=>{
    this.setState({
      treeLoading: true,
    })
    const msg = await getPermissions();
    if(msg.error.length === 0){
      let data = await this.handlePermissionsList(msg.data.one);
      this.setState({
        permissionsList: data
      })
    }else{
      message.error(msg.error[0].message)
    }
    this.setState({
      treeLoading: false,
    })
  }

  handlePermissionsList=(menuList)=>{
    menuList.map((value)=>{
      value.title = value.name;
      value.key = value.id;
      if(value.children){
        this.handlePermissionsList(value.children);
      }
      return value
    })
    return menuList;
  }

  componentDidMount() {
    this.getPermissionsList();
  }

  getRolePermission =async ()=>{
    this.setState({
      roleNameLoading: true,
      treeLoading: true,
    })
    const msg = await getRolePermission(this.props.roleData.id);
    if(msg.error.length === 0){
      let idList=[];
      msg.data.map((item)=>{
        idList.push(
          item.pid
        )
      })
      this.setState({
        checkedKeys:idList,
      })
      this.formRef.current.setFieldsValue({
        roleName:msg.data[0].rname
      });
    }else{
      message.error(msg.error[0].message);
    }
    this.setState({
      roleNameLoading: false,
      treeLoading: false,
    })
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if(!prevProps.visible && this.props.roleData){
      this.getRolePermission();
    }
  }


  formRef = React.createRef();

  render() {
    const {roleData} = this.props;
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title={roleData?'编辑角色':'添加角色'}
        modalProps={{
          destroyOnClose: true,
          onCancel: (e) => {e.stopPropagation();this.setState({checkedKeys:''});this.props.onCancel();},
        }}
        onFinish={roleData?this.finishUpdataRole : this.finishAddRole}
      >
        <ProForm.Group>
          <Spin spinning={this.state.roleNameLoading}>
            <ProFormText
              rules={
                [{
                  required: true,
                  message: '请输入角色名称!',
                }]
              }
              width="xl"
              name="roleName"
              label="角色名称："
              placeholder="请输入角色名称"
            />
          </Spin>
        </ProForm.Group>
        <Form.Item name='tree'>
          <Spin spinning={this.state.treeLoading}>
            <Tree
              checkable
              onExpand={this.onExpand}
              expandedKeys={this.state.expandedKeys}
              autoExpandParent={this.state.autoExpandParent}
              onCheck={this.onCheck}
              checkedKeys={this.state.checkedKeys}
              onSelect={this.onSelect}
              selectedKeys={this.state.selectedKeys}
              treeData={this.state.permissionsList}
            />
          </Spin>
        </Form.Item>
      </ModalForm>
    )
  }
}

export default EditRole;
