import React,{Component} from 'react';
import {roleResources} from '@/utils/dataDic';
import ProForm, {ModalForm, ProFormCheckbox} from "@ant-design/pro-form";
import {addResources,getResourcesDetail} from '../services/API';
import { LoadingOutlined } from '@ant-design/icons';
import {Form, message,Spin} from "antd";

const antIcon = <LoadingOutlined style={{ fontSize: 24 }} spin />;

class Turnover extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading: false
    }
    this.addResources = this.addResources.bind(this);
    this.getResourcesDetail = this.getResourcesDetail.bind(this);
  }

  addResources= async (value)=>{
    message.loading({content:'保存中...',key:'addResources'});
    const msg = await addResources({
      rid: this.props.roleData.id,
      resources:value.resources.join(","),
    });
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addResources',duration:2.5});
      this.props.tableRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addResources',duration:2.5});
    }
  }

  getResourcesDetail= async ()=>{
    this.setState({
      loading: true
    })
    const msg = await getResourcesDetail(this.props.roleData.id);
    if(msg.error.length === 0){
      let resourcesData=[];
      for(let i=0;i<msg.data.length;i++){
        resourcesData.push(msg.data[i].resources.toString())
      }
      this.formRef.current.setFieldsValue({
        resources: resourcesData,
      });
    }else{
      message.error(msg.error[0].message);
    }
    this.setState({
      loading: false,
    })
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if(!prevProps.visible && this.props.roleData){
      this.getResourcesDetail();
    }
  }

  formRef=React.createRef();

  render() {
    return(
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title='离职转交配置'
        modalProps={{
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();},
        }}
        onFinish={this.addResources}
        layout='horizonta'
      >
        <Form.Item label="角色名称">
          <span className="ant-form-text">{this.props.roleData.roleName}</span>
        </Form.Item>
        <ProForm.Group>
          <Spin indicator={antIcon} spinning={this.state.loading}>
            <ProFormCheckbox.Group
              rules={[
                {
                  required:true,
                  message:'请选择离职转交配置'
                }
              ]}
              name="resources"
              label="请选择离职转交配置"
              options={roleResources}
            />
          </Spin>
        </ProForm.Group>
      </ModalForm>
    )
  }
}

export default Turnover;
