import React,{Component} from 'react';
import {Button, message, Popconfirm} from "antd";
import DataTable from "@/components/common/DataTable";
import EditRole from './components/editRole';
import {PlusOutlined} from "@ant-design/icons";
import {deleteRole} from './services/API';
import Turnover from './components/turnover';
import moment from "moment";

class RoleManage extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns: [
        {
          title: '角色名称',
          dataIndex: "roleName",
          key: "roleName",
          searchBool: true,
        }, {
          title: '创建人',
          dataIndex: 'creater',
          key: 'creater',
        }, {
          title: '创建时间',
          dataIndex: 'createTime',
          key: 'createTime',
          render: (text)=>(
            <span>{moment(text).format('YYYY-MM-DD')}</span>
          )
        },
        {
          title: '离职转交配置',
          dataIndex: 'id',
          key: 'id',
          render: (text ,record, key ,action)=>{
            return (
              <Button type='primary' onClick={(e)=>{
                e.stopPropagation();
                this.setState({
                  turnoverVisible: true,
                  roleDataTurnover: record,
                })
              }}>
                离职转交配置
              </Button>
            )
          }
        },
        {
          title: '操作',
          dataIndex: 'id',
          key: 'deleteRole',
          render: (text ,record, key ,action)=>{
            return (
              <Popconfirm
                title="是否真的删除?"
                onConfirm={(e)=>{e.stopPropagation();this.deleteRole(text,action)}}
                okText="确认"
                cancelText="取消"
                placement="topLeft">
                  <Button type="primary" danger onClick={(e)=>e.stopPropagation()}>
                    删除
                  </Button>
              </Popconfirm>
            )
          }
        }
      ],
      visible: false,
      turnoverVisible: false,
      roleData: '',
      roleDataTurnover: '',
    }
  }

  deleteRole= async (id,action)=>{
    message.loading({content:'删除中...',key:'deleteRole'})
    const msg = await deleteRole({data:JSON.stringify([id])});
    if(msg.error.length === 0){
      message.success({content:'删除成功',key:'deleteRole',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'deleteRole',duration:2.5});
    }
  }



  render() {
    const ref = React.createRef();
    return(
      <>
        <DataTable
          ref={ref}
          headerTitle='角色管理'
          url='/api/admin/roles'
          method='post'
          rowKey='id'
          columns={this.state.columns}
          search={{
            filterType: 'query',
            labelWidth: 'auto',
            defaultCollapsed: false,
          }}
          onRow={(record)=>({
            onClick:(e)=>{
              e.stopPropagation();
              this.setState({
                visible:true,
                roleData:record,
              })
            }
          })}
          toolBarRender={[
            <Button
              type="primary"
              key='addRoles'
              icon={<PlusOutlined />}
              onClick={(e)=>{e.stopPropagation();this.setState({visible:true})}}>
              新增角色
            </Button>
          ]}
        />
        <EditRole
          roleData={this.state.roleData}
          tableRef={ref}
          visible={this.state.visible}
          onCancel={()=>{
            this.setState({
              visible: false,
              roleData: '',
            })
          }}/>
          <Turnover
            roleData={this.state.roleDataTurnover}
            tableRef={ref}
            visible={this.state.turnoverVisible}
            onCancel={()=>{
              this.setState({
                turnoverVisible: false,
                roleDataTurnover: '',
              })
            }}/>
      </>
    )
  }
}

export default RoleManage;
